pub struct EncodedRows {
pub terms: Vec<TermRow>,
pub triples: Vec<TripleRow>,
}Expand description
Everything that must be written so that an encoded term can be decoded later.
Fields
terms: Vec<TermRow>triples: Vec<TripleRow>Implementations
Sourceimpl EncodedRows
impl EncodedRows
Sourcepub fn term(&mut self, term: TermRef<'_>) -> i64
pub fn term(&mut self, term: TermRef<'_>) -> i64
Encodes a term, recording the rows needed to decode it.
pub fn iri(&mut self, iri: &str) -> i64
pub fn bnode(&mut self, label: &str) -> i64
pub fn subject(&mut self, s: NamedOrBlankNodeRef<'_>) -> i64
pub fn graph(&mut self, g: GraphNameRef<'_>) -> i64
pub fn triple(&mut self, t: TripleRef<'_>) -> i64
pub fn is_empty(&self) -> bool