TermRow

Struct TermRow 

pub struct TermRow {
    pub id: i64,
    pub lex: String,
    pub dt: Option<String>,
    pub lang: Option<String>,
    pub dir: Option<i64>,
    pub num: Option<f64>,
    pub nt: Option<i64>,
    pub ts: Option<f64>,
}
The row stored in terms for a hashed term.

Fields

id: i64lex: String

IRI, blank node label, or literal lexical form.

dt: Option<String>

Datatype IRI, only for Tag::Typed.

lang: Option<String>

Language tag, for Tag::LangString and Tag::DirLangString.

dir: Option<i64>

Base direction (1 = ltr, 2 = rtl) for Tag::DirLangString; for date/time literals, whether the value has a timezone (1) or not (0).

num: Option<f64>

Numeric value for numeric datatypes, or 0/1 for non-canonical xsd:boolean.

nt: Option<i64>

Numeric type rank (see numeric_type).

ts: Option<f64>

xsd:dateTime / xsd:date as seconds since the Unix epoch (timezone-normalized).