Module query

Module query 

Query compilation entry point, execution job and result decoding.

Structs

CompiledQuery
A query compiled to SQL.
QueryJob
Runs a compiled query.

Enums

QueryOutput
Decoded query results.

Functions

compile_query
Compiles a SPARQL query to SQL. Returns Error::Unsupported for anything that cannot be expressed in SQL on this backend.