problems

Function problems 

pub fn problems(rows: &[Vec<Option<Term>>]) -> Vec<String>
What is wrong with the registry described by ?g ?p ?o rows (see entries_query): the violations of the registry’s SHACL shapes (oxl:RegistrationShape in VOCABULARY), found without a SHACL engine, one message per violation. Empty means valid.

A node is checked when it has a role class, oxl:SystemGraph, or a registration property.