pub struct ShapeIndex {
pub by_class: BTreeMap<NamedNode, BTreeMap<NamedNode, PropertyShape>>,
}Expand description
The compiled property shapes, by target class and path.
Fields
by_class: BTreeMap<NamedNode, BTreeMap<NamedNode, PropertyShape>>Implementations
Sourceimpl ShapeIndex
impl ShapeIndex
pub fn is_empty(&self) -> bool
Sourcepub fn get(&self, class: &NamedNode, path: &NamedNode) -> Option<&PropertyShape>
pub fn get(&self, class: &NamedNode, path: &NamedNode) -> Option<&PropertyShape>
The shapes of a path for a node with these classes.
Sourcepub fn load_request(caps: &Capabilities) -> Request
pub fn load_request(caps: &Capabilities) -> Request
Statements loading both tables.
Sourcepub fn from_response(response: &Response) -> Result<Self>
pub fn from_response(response: &Response) -> Result<Self>
Decodes the response of Self::load_request.