SPARQL UPDATE planning.
Operations become SQL statements appended to one atomic request, so a whole update
request is applied as a single transaction (one D1 batch). Operations that cannot be
compiled are reported as PlannedOp::Fallback for sync backends.
Enums
- Planned
Op - A planned update operation.
Functions
- delete_
data_ quads - Converts
DELETE DATAquads. - explain_
plan - Describes how each operation of an update runs (for
explain_update()). - graph_
name_ id - Graph id helper used by drivers.
- insert_
data_ quads INSERT DATAquads with fresh blank nodes.- plan_
update - Plans a SPARQL update.
- plan_
update_ with - Plans a SPARQL update using planner statistics.