as_of_sql

Function as_of_sql 

pub fn as_of_sql(t: &str) -> String
SQL: the (s, p, o, g) table of the store as it was at tick t (a SQL expression): the quads whose latest logged change at or before t is an addition.