pub fn commits_rel_sql(state: &VersionState) -> StringExpand description
SQL: the Datalog relation commit(c, parent, time, author): every commit (its tick as an
inline integer), the commit before it, and its time and author terms.
pub fn commits_rel_sql(state: &VersionState) -> StringSQL: the Datalog relation commit(c, parent, time, author): every commit (its tick as an
inline integer), the commit before it, and its time and author terms.