pub struct Versioned<J> { /* private fields */ }Expand description
A job whose atomic writes open a tick (for hosts that run requests themselves, such as the JavaScript drivers).
Implementations
Sourceimpl<J> Versioned<J>
impl<J> Versioned<J>
pub fn new(inner: J, level: Versioning, info: CommitInfo) -> Self