Module update

Module update 

SPARQL UPDATE planning.

Operations become SQL statements appended to one atomic request, so a whole update request is applied as a single transaction (one D1 batch). Operations that cannot be compiled are reported as PlannedOp::Fallback for sync backends.

Enums

PlannedOp
A planned update operation.

Functions

delete_data_quads
Converts DELETE DATA quads.
explain_plan
Describes how each operation of an update runs (for explain_update()).
graph_name_id
Graph id helper used by drivers.
insert_data_quads
INSERT DATA quads with fresh blank nodes.
plan_update
Plans a SPARQL update.
plan_update_with
Plans a SPARQL update using planner statistics.